import { useState, useEffect } from './index';
import { resolveHookState } from './misc/hookState';
export function createGlobalState(initialState) {
    const store = {
        state: initialState instanceof Function ? initialState() : initialState,
        setState(nextState) {
            store.state = resolveHookState(nextState, store.state);
            store.setters.forEach((setter) => setter(store.state));
        },
        setters: [],
    };
    return () => {
        const [globalState, stateSetter] = useState(store.state);
        useEffect(() => () => {
            store.setters = store.setters.filter((setter) => setter !== stateSetter);
        });
        useEffect(() => {
            if (!store.setters.includes(stateSetter)) {
                store.setters.push(stateSetter);
            }
        });
        return [globalState, store.setState];
    };
}
export default createGlobalState;
//# sourceMappingURL=createGlobalState.js.map