import useMountedState from "./useMountedState";
import { useReactive, useRef } from "./index";
export default function useAsyncFn(fn, initialState = { loading: false }) {
    const lastCallId = useRef(0);
    const isMounted = useMountedState();
    const [state, set] = useReactive(initialState);
    const callback = (...args) => {
        const callId = ++lastCallId.value;
        state.loading = true;
        return fn(...args).then((value) => {
            isMounted() && callId === lastCallId.value && set({ value, loading: false });
            return value;
        }, (error) => {
            isMounted() && callId === lastCallId.value && set({ error, loading: false });
            return error;
        });
    };
    return [state, callback];
}
//# sourceMappingURL=useAsyncFn.js.map