import { computed, isRef } from 'vue';
import { useRef, useState } from './index';
import { resolveHookState } from './misc/hookState';
export default function useCounter(initialValue = 0, max = null, min = null) {
    let init = isRef(initialValue) ? initialValue : useRef(resolveHookState(initialValue));
    if (typeof init.value !== 'number') {
        console.error('initialValue has to be a number, got ' + typeof initialValue);
    }
    const minRef = useRef(min);
    const maxRef = useRef(max);
    if (typeof minRef.value === 'number') {
        init.value = Math.max(init.value, minRef.value);
    }
    else if (minRef.value !== null) {
        console.error('min has to be a number, got ' + typeof minRef.value);
    }
    if (typeof maxRef.value === 'number') {
        init.value = Math.min(init.value, maxRef.value);
    }
    else if (maxRef.value !== null) {
        console.error('max has to be a number, got ' + typeof maxRef.value);
    }
    const [current, setInternal] = useState(init.value);
    const get = () => {
        return current.value;
    };
    const set = (newState) => {
        const prevState = get();
        let rState = resolveHookState(newState, prevState);
        if (prevState !== rState) {
            if (typeof minRef.value === 'number') {
                rState = Math.max(rState, minRef.value);
            }
            if (typeof maxRef.value === 'number') {
                rState = Math.min(rState, maxRef.value);
            }
            prevState !== rState && setInternal(rState);
        }
    };
    return [
        computed(() => {
            return current.value;
        }),
        {
            get,
            set,
            inc: (delta = 1) => {
                const rDelta = resolveHookState(delta, get());
                if (typeof rDelta !== 'number') {
                    console.error('delta has to be a number or function returning a number, got ' + typeof rDelta);
                }
                set((num) => num + rDelta);
            },
            dec: (delta = 1) => {
                const rDelta = resolveHookState(delta, get());
                if (typeof rDelta !== 'number') {
                    console.error('delta has to be a number or function returning a number, got ' + typeof rDelta);
                }
                set((num) => num - rDelta);
            },
            reset: (value = initialValue) => {
                const rValue = isRef(value) ? value.value : resolveHookState(value, get());
                if (typeof rValue !== 'number') {
                    console.error('value has to be a number or function returning a number, got ' + typeof rValue);
                }
                // eslint-disable-next-line react-hooks/exhaustive-deps
                init.value = rValue;
                set(rValue);
            },
        },
    ];
}
//# sourceMappingURL=useCounter.js.map