import { isRef, unref, watch } from 'vue';
import useEvent from './useEvent';
import { noop } from './misc/util';
import { useState } from "./index";
const createKeyPredicate = (keyFilter) => typeof keyFilter === 'function'
    ? keyFilter
    : typeof keyFilter === 'string'
        ? (event) => event.key === keyFilter
        : keyFilter
            ? () => true
            : () => false;
const useKey = (key, fn = noop, opts = {}) => {
    const { event = 'keydown', target, options } = opts;
    const [predicate, setPredicate] = useState(() => createKeyPredicate(unref(key)));
    if (isRef(key)) {
        watch(key, () => {
            setPredicate(() => createKeyPredicate(unref(key)));
        });
    }
    const handler = (handlerEvent) => {
        if (unref(predicate)(handlerEvent)) {
            return fn(handlerEvent);
        }
    };
    useEvent(event, handler, target, options);
};
export default useKey;
//# sourceMappingURL=useKey.js.map