import { ref as useRef, unref } from 'vue';
import { off, on } from './misc/util';
const isTouchEvent = (ev) => {
    return 'touches' in ev;
};
const preventDefault = (ev) => {
    if (!isTouchEvent(ev))
        return;
    if (ev.touches.length < 2 && ev.preventDefault) {
        ev.preventDefault();
    }
};
const useLongPress = (callback, options = { isPreventDefault: true, delay: 300 }) => {
    const timeout = useRef();
    const target = useRef();
    const start = (event) => {
        // prevent ghost click on mobile devices
        if (unref(options.isPreventDefault) && event.target) {
            on(event.target, 'touchend', preventDefault, { passive: false });
            target.value = event.target;
        }
        timeout.value = setTimeout(() => unref(callback)(event), unref(options.delay));
    };
    const clear = () => {
        // clearTimeout and removeEventListener
        timeout.value && clearTimeout(timeout.value);
        if (unref(options.isPreventDefault) && target.value) {
            off(target.value, 'touchend', preventDefault);
        }
    };
    return {
        onMousedown: (e) => start(e),
        onTouchstart: (e) => start(e),
        onMouseup: clear,
        onMouseleave: clear,
        onTouchend: clear,
    };
};
export default useLongPress;
//# sourceMappingURL=useLongPress.js.map