import { useEffect, useReadonly, useState } from './index';
import { isBrowser, noop } from './misc/util';
const defaultState = {
    x: 0,
    y: 0,
    width: 0,
    height: 0,
    top: 0,
    left: 0,
    bottom: 0,
    right: 0,
};
function useMeasure() {
    const [element, ref] = useState(null);
    const [rect, setRect] = useReadonly(defaultState);
    const observer = new window.ResizeObserver((entries) => {
        if (entries[0]) {
            const { x, y, width, height, top, left, bottom, right } = entries[0].contentRect;
            setRect({ x, y, width, height, top, left, bottom, right });
        }
    });
    useEffect(() => {
        if (!element) {
            return;
        }
        observer.observe(element.value);
        return () => {
            observer.disconnect();
        };
    }, [element]);
    return [ref, rect];
}
export default isBrowser && typeof window.ResizeObserver !== 'undefined'
    ? useMeasure
    : (() => [noop, defaultState]);
//# sourceMappingURL=useMeasure.js.map