import { useEffect, useReadonly, useRef } from './index';
import { unref } from "vue";
export default function useMultiStateValidator(states, validator, initialValidity = [undefined]) {
    if (typeof states !== 'object') {
        throw new Error('states expected to be an object or array, got ' + typeof states);
    }
    const validatorInner = useRef(validator);
    const statesInner = useRef(states);
    validatorInner.value = validator;
    statesInner.value = states;
    const [validity, setValidity] = useReadonly(initialValidity);
    const validate = () => {
        if (validatorInner.value.length >= 2) {
            validatorInner.value(statesInner.value.map(item => unref(item)), setValidity);
        }
        else {
            setValidity(validatorInner.value(statesInner.value.map(item => unref(item))));
        }
    };
    useEffect(() => {
        validate();
    }, Object.values(states));
    return [validity, validate];
}
//# sourceMappingURL=useMultiStateValidator.js.map