import { useEffect, useRef } from './index';
import { computed } from "vue";
// https://developer.mozilla.org/zh-CN/docs/Web/API/Window/requestAnimationFrame
export default function useRafLoop(callback, initiallyActive = true) {
    const raf = useRef(null);
    const rafActivity = useRef(false);
    const rafCallback = useRef(callback);
    rafCallback.value = callback;
    const step = (time) => {
        if (rafActivity.value) {
            rafCallback.value(time);
            raf.value = requestAnimationFrame(step);
        }
    };
    const stop = () => {
        if (rafActivity.value) {
            rafActivity.value = false;
            raf.value && cancelAnimationFrame(raf.value);
        }
    };
    const start = () => {
        if (!rafActivity.value) {
            rafActivity.value = true;
            raf.value = requestAnimationFrame(step);
        }
    };
    const isActive = computed(() => {
        return rafActivity.value;
    });
    useEffect(() => {
        if (initiallyActive) {
            start();
        }
        return stop;
    });
    return [stop, start, isActive];
}
//# sourceMappingURL=useRafLoop.js.map