import { isRef, onUnmounted, unref } from 'vue';
import { sources, useEffect, useRef, useState } from './index';
const useThrottle = (value, ms = 200) => {
    const [state, setState] = useState(isRef(value) ? unref(value) : value);
    const timeout = useRef();
    const nextValue = useRef(null);
    const hasNextValue = useRef(0);
    useEffect(() => {
        if (!timeout.value) {
            setState(value);
            const timeoutCallback = () => {
                if (hasNextValue.value) {
                    hasNextValue.value = false;
                    setState(nextValue.value);
                    timeout.value = setTimeout(timeoutCallback, ms);
                }
                else {
                    timeout.value = undefined;
                }
            };
            timeout.value = setTimeout(timeoutCallback, ms);
        }
        else {
            nextValue.value = unref(value);
            hasNextValue.value = true;
        }
    }, sources([value]));
    onUnmounted(() => {
        timeout.value && clearTimeout(timeout.value);
    });
    return state;
};
export default useThrottle;
//# sourceMappingURL=useThrottle.js.map